==> jview-0.1.2.tar.gz: jview-0.1.2/ubox.h <==
/*  jview : Image viewer
 *  Copyright (C) 1998 david Ramboz
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __UBOX_H__
#define __UBOX_H__

#include <gdk/gdk.h>
#include <gtk/gtksignal.h>
#include <gtk/gtkalignment.h>
#include <gtk/gtkhscrollbar.h>
#include <gtk/gtkvscrollbar.h>
#include <gtk/gtkcontainer.h>
#include <gtk/gtkenums.h>

enum {
    UBOX_FROZEN           = 1 << 1,
    UBOX_DRAG_SELECTION   = 1 << 2,
    UBOX_ADD_MODE         = 1 << 3
};

#define TYPE_UBOX                  (ubox_get_type ())
#define UBOX(obj)                  (GTK_CHECK_CAST ((obj), TYPE_UBOX, UBox))
#define UBOX_CLASS(klass)          (GTK_CHECK_CLASS_CAST ((klass), TYPE_UBOX, GtkUboxClass))
#define IS_UBOX(obj)               (GTK_CHECK_TYPE ((obj), TYPE_UBOX))
#define IS_UBOX_CLASS(klass)       (GTK_CHECK_CLASS_TYPE ((klass), TYPE_UBOX))
#define UBOX_CELL( ubox)           ((UBoxCell*) (ubox)->data)
#define UBOX_FLAGS( ubox)     (UBOX( ubox)->flags)  
#define UBOX_SET_FLAG( ubox, flag)   (UBOX( ubox)->flags |= flag)
#define UBOX_UNSET_FLAG( ubox, flag) (UBOX( ubox)->flags &= ~flag)

typedef struct _UBox UBox;
typedef struct _UBoxClass UBoxClass;
typedef struct _UBoxCell UBoxCell;


struct _UBox {
    GtkContainer container;

    gint flags;

    GdkWindow *cells_area;
    gint cells_area_width;
    gint cells_area_height;

    GSList *children;
    guint child_count;

    gint cell_width;
    gint cell_height;
    gint cells_per_row;

    gint hoffset;
    gint voffset;

    gint cell_xpad;
    gint cell_ypad;

    GtkWidget *hscrollbar;
    GtkWidget *vscrollbar;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;

    GtkSelectionMode selection_mode;
    GSList *selection;

    gint focus_cell;
    /* dragging the selection */
    gint anchor;
    gint drag_pos;
    guint htimer;
    guint vtimer;
};

struct _UBoxClass {
    GtkContainerClass parent_class;

    void     (*draw_cell) ( UBox *ubox,
			    UBoxCell *cell,
			    GdkRectangle *cell_area,
			    GdkRectangle *area);
    void     (*select_cell) ( UBox *ubox,
			      gint cell_no);
    void     (*unselect_cell) ( UBox *ubox,
				gint cell_no);
};
	    
struct _UBoxCell {
    GtkStateType state;

    gpointer data;
};

GtkType        ubox_get_type( void);

GtkWidget*     ubox_new( gint cell_width,
			 gint cell_height);

UBoxCell*      ubox_append( UBox *ubox, 
			    gpointer data);
void           ubox_remove( UBox *ubox,
			    UBoxCell *cell);
void           ubox_resize( UBox *ubox,
			    gint cell_width,
			    gint cell_height);
void           ubox_clear( UBox *ubox);

void           ubox_select_cell( UBox *ubox, UBoxCell *cell);
void           ubox_unselect_cell( UBox *ubox, UBoxCell *cell);
void           ubox_moveto( UBox *ubox, UBoxCell *cell);

gint           ubox_cell_from_coord( UBox *ubox, gint x, gint y);
gint           ubox_get_cell_coord( UBox *ubox, gint cell_no, gint *x, gint *y);

GList*         ubox_get_selection( UBox *ubox);
void           ubox_set_selection_mode( UBox *ubox, GtkSelectionMode mode);
#define        ubox_get_cell( ubox, cell_no) (g_slist_nth_data( ubox->children, cell_no))

#endif /* __UBOX_H__ */

==> jview-0.1.3.tar.gz: jview-0.1.3/ubox.h <==
/*  jview : Image viewer
 *  Copyright (C) 1998 david Ramboz
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __UBOX_H__
#define __UBOX_H__

#include <gdk/gdk.h>
#include <gtk/gtksignal.h>
#include <gtk/gtkalignment.h>
#include <gtk/gtkhscrollbar.h>
#include <gtk/gtkvscrollbar.h>
#include <gtk/gtkcontainer.h>
#include <gtk/gtkenums.h>

enum {
    UBOX_FROZEN           = 1 << 1,
    UBOX_DRAG_SELECTION   = 1 << 2,
    UBOX_ADD_MODE         = 1 << 3,
    UBOX_ONE_CELL_PER_ROW = 1 << 4
};

#define TYPE_UBOX                  (ubox_get_type ())
#define UBOX(obj)                  (GTK_CHECK_CAST ((obj), TYPE_UBOX, UBox))
#define UBOX_CLASS(klass)          (GTK_CHECK_CLASS_CAST ((klass), TYPE_UBOX, GtkUboxClass))
#define IS_UBOX(obj)               (GTK_CHECK_TYPE ((obj), TYPE_UBOX))
#define IS_UBOX_CLASS(klass)       (GTK_CHECK_CLASS_TYPE ((klass), TYPE_UBOX))
#define UBOX_CELL( ubox)           ((UBoxCell*) (ubox)->data)
#define UBOX_FLAGS( ubox)     (UBOX( ubox)->flags)  
#define UBOX_SET_FLAG( ubox, flag)   (UBOX( ubox)->flags |= flag)
#define UBOX_UNSET_FLAG( ubox, flag) (UBOX( ubox)->flags &= ~flag)

typedef struct _UBox UBox;
typedef struct _UBoxClass UBoxClass;
typedef struct _UBoxCell UBoxCell;


struct _UBox {
    GtkContainer container;

    gint flags;

    GdkWindow *cells_area;
    gint cells_area_width;
    gint cells_area_height;

    GSList *children;
    guint child_count;

    gint cell_width;
    gint cell_height;
    gint cells_per_row;
 
    gint hoffset;
    gint voffset;

    GtkWidget *hscrollbar;
    GtkWidget *vscrollbar;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;

    GtkSelectionMode selection_mode;
    GSList *selection;

    gint focus_cell;

    /* dragging the selection */
    gint anchor;
    gint drag_pos;
    guint htimer;
    guint vtimer;
};

struct _UBoxClass {
    GtkContainerClass parent_class;

    void     (*draw_cell) ( UBox *ubox,
			    UBoxCell *cell,
			    GdkRectangle *cell_area,
			    GdkRectangle *area);
    void     (*select_cell) ( UBox *ubox,
			      gint cell_no);
    void     (*unselect_cell) ( UBox *ubox,
				gint cell_no);
};
	    
struct _UBoxCell {
    GtkStateType state;

    gpointer data;
};

GtkType        ubox_get_type( void);

GtkWidget*     ubox_new( gint cell_width,
			 gint cell_height);

UBoxCell*      ubox_append( UBox *ubox, 
			    gpointer data);
void           ubox_remove( UBox *ubox,
			    UBoxCell *cell);
void           ubox_resize( UBox *ubox,
			    gint cell_width,
			    gint cell_height);
void           ubox_clear( UBox *ubox);

void           ubox_set_one_cell_per_row( UBox *ubox, gint one);

void           ubox_select_cell( UBox *ubox, UBoxCell *cell);
void           ubox_unselect_cell( UBox *ubox, UBoxCell *cell);
void           ubox_moveto( UBox *ubox, UBoxCell *cell);

gint           ubox_cell_from_coord( UBox *ubox, gint x, gint y);
gint           ubox_get_cell_coord( UBox *ubox, gint cell_no, gint *x, gint *y);

GList*         ubox_get_selection( UBox *ubox);
void           ubox_set_selection_mode( UBox *ubox, GtkSelectionMode mode);
#define        ubox_get_cell( ubox, cell_no) (g_slist_nth_data( ubox->children, cell_no))

#endif /* __UBOX_H__ */
